Learn R Programming

pwr (version 1.0)

pwr.2p.test: Power calculation for two proportions (same sample sizes)

Description

Compute power of test, or determine parameters to obtain target power (same as power.prop.test).

Usage

pwr.2p.test(h = NULL, n = NULL, sig.level = 0.05, power = NULL, alternative = c("two.sided", "one.sided"))

Arguments

h
Effect size
n
Number of observations (per sample)
sig.level
Significance level (Type I error probability)
power
Power of test (1 minus Type II error probability)
alternative
One- or two-sided test

Value

  • Object of class 'power.htest', a list of the arguments (including the computed one) augmented with 'method' and 'note' elements.

Details

Exactly one of the parameters 'h','n', 'power' and 'sig.level' must be passed as NULL, and that parameter is determined from the others. Notice that the last one has non-NULL default so NULL must be explicitly passed if you want to compute it.

References

J. Cohen (1988) Statistical power analysis for the behavioral scientist. Lawrence Erlbaum Associates, publishers.

See Also

pwr.2p2n.test, power.prop.test

Examples

Run this code
## Exercise 6.1 p. 198 from Cohen (1988)
pwr.2p.test(h=0.3,n=80,sig.level=0.05,alternative="one.sided")

## Exercise 6.6 p. 206 from Cohen (1988)
pwr.p.test(h=0.3,power=0.8,sig.level=0.05,alternative="one.sided")

Run the code above in your browser using DataLab