pwr.anova.test: Power calculations for balanced one-way analysis of variance tests
Description
Compute power of test or determine parameters to obtain target
power (same as power.anova.test except for the definition of the effect size).
Usage
pwr.anova.test(k = NULL, n = NULL, f = NULL, sig.level = 0.05, power = NULL)
Arguments
k
Number of groups
n
Number of observations (per group)
f
Effect size
sig.level
Significance level (Type I error probability)
power
Power of test (1 minus Type II error probability)
Value
Object of class 'power.htest', a list of the arguments
(including the computed one) augmented with 'method' and 'note'
elements.
Details
Exactly one of the parameters 'k','n','f','power' and
'sig.level' must be passed as NULL, and that parameter is
determined from the others. Notice that the last one has non-NULL
default so NULL must be explicitly passed if you want to compute
it.
References
J. Cohen (1988) Statistical power analysis for the
behavioral scientist. Lawrence Erlbaum Associates, publishers.
## Exercise 8.1 P. 357 from Cohen (1988) pwr.anova.test(f=0.28,k=4,n=20,sig.level=0.05)
## Exercise 8.10 p. 391pwr.anova.test(f=0.28,k=4,power=0.80,sig.level=0.05)