Learn R Programming

pwr (version 1.0)

pwr.chisq.test: power calculations for chi-squared tests

Description

Compute power of test or determine parameters to obtain target power in chi-squared tests (independence or goodness-of-fit).

Usage

pwr.chisq.test(w = NULL, N = NULL, df = NULL, sig.level = 0.05, power = NULL)

Arguments

w
Effect size
N
Total number of observations
df
Degrees of freedom (depends on the chosen test)
sig.level
Significance level (Type I error probability)
power
Power of test (1 minus Type II error probability)

Value

  • Object of class 'power.htest', a list of the arguments (including the computed one) augmented with 'method' and 'note' elements.

Details

Exactly one of the parameters 'w','N','power' and 'sig.level' must be passed as NULL, and that parameter is determined from the others. Notice that the last one has non-NULL default so NULL must be explicitly passed if you want to compute it.

References

J. Cohen (1988) Statistical power analysis for the behavioral scientist. Lawrence Erlbaum Associates, publishers.

Examples

Run this code
## Exercise 7.1 p. 249 from Cohen (1988) 
pwr.chisq.test(w=0.289,df=(4-1),N=100,sig.level=0.05)

## Exercise 7.3 p. 251
pwr.chisq.test(w=0.346,df=(2-1)*(3-1),N=140,sig.level=0.01)

## Exercise 7.8 p. 270
pwr.chisq.test(w=0.1,df=(5-1)*(6-1),power=0.80,sig.level=0.05)

Run the code above in your browser using DataLab