Learn R Programming

pwr (version 1.0)

pwr.norm.test: Power calculations for the mean of a normal distribution (known variance)

Description

Compute power of test or determine parameters to obtain target power.

Usage

pwr.norm.test(d = NULL, n = NULL, sig.level = 0.05, power = NULL, alternative = c("two.sided", "one.sided"))

Arguments

d
Effect size d=mu-mu0
n
Number of observations
sig.level
Significance level (Type I error probability)
power
Power of test (1 minus Type II error probability)
alternative
One- or two-sided test

Value

  • Object of class 'power.htest', a list of the arguments (including the computed one) augmented with 'method' element.

Details

Exactly one of the parameters 'd','n','power' and 'sig.level' must be passed as NULL, and that parameter is determined from the others. Notice that the last one has non-NULL default so NULL must be explicitly passed if you want to compute it.

References

J. Cohen (1988) Statistical power analysis for the behavioral scientist. Lawrence Erlbaum Associates, publishers.

Examples

Run this code
## Power at mu=105 for H0 : mu=100 against H1 : mu>100 (sigma=15) 20 observations (alpha=0.05) 
sigma<-15
c<-100
mu<-105
d<-(mu-c)/sigma
pwr.norm.test(d=d,n=20,sig.level=0.05,alternative="one.sided")

## Sample size of the test for power=0.80
pwr.norm.test(d=d,power=0.8,sig.level=0.05,alternative="one.sided")

## Power function of the same test
mu<-seq(95,125,l=100)
d<-(mu-c)/sigma
plot(d,pwr.norm.test(d=d,n=20,sig.level=0.05,alternative="one.sided")$power,type="l",ylim=c(0,1))
abline(h=0.05)
abline(h=0.80)

## Power function for the two-sided alternative
plot(d,pwr.norm.test(d=d,n=20,sig.level=0.05,alternative="two.sided")$power,type="l",ylim=c(0,1))
abline(h=0.05)
abline(h=0.80)

Run the code above in your browser using DataLab