Learn R Programming

pwr (version 1.0)

pwr.p.test: Power calculations for proportion tests (one sample)

Description

Compute power of test or determine parameters to obtain target power.

Usage

pwr.p.test(h = NULL, n = NULL, sig.level = 0.05, power = NULL, alternative = c("two.sided", "one.sided"))

Arguments

h
Effect size
n
Number of observations
sig.level
Significance level (Type I error probability)
power
Power of test (1 minus Type II error probability)
alternative
One- or two-sided test

Value

  • Object of class 'power.htest', a list of the arguments (including the computed one) augmented with 'method' element.

Details

These calculations use arcsine transformation of the proportion (see Cohen (1988)) Exactly one of the parameters 'h','n','power' and 'sig.level' must be passed as NULL, and that parameter is determined from the others. Notice that the last one has non-NULL default so NULL must be explicitly passed if you want to compute it.

References

J. Cohen (1988) Statistical power analysis for the behavioral scientist. Lawrence Erlbaum Associates, publishers.

Examples

Run this code
## Exercise 6.5 p. 203 from Cohen (1988)
pwr.p.test(h=0.2,n=60,sig.level=0.05,alternative="two.sided")

## Exercise 6.8 p. 208 from Cohen (1988)
pwr.p.test(h=0.2,power=0.95,sig.level=0.05,alternative="two.sided")

Run the code above in your browser using DataLab