Learn R Programming

pwr (version 1.0)

pwr.r.test: Power calculations for correlation tests

Description

Compute power of test or determine parameters to obtain target power.

Usage

pwr.r.test(n = NULL, r = NULL, sig.level = 0.05, power = NULL, alternative = c("two.sided", "one.sided"))

Arguments

n
Number of observations
r
Linear correlation coefficient
sig.level
Significance level (Type I error probability)
power
Power of test (1 minus Type II error probability)
alternative
One- or two-sided test

Value

  • Object of class 'power.htest', a list of the arguments (including the computed one) augmented with 'method' element.

Details

These calculations use the Z' transformation of correlation coefficient : Z'=arctanh(r)+r/(2*(n-1)) (see Cohen (1988) p.546). Exactly one of the parameters 'r','n','power' and 'sig.level' must be passed as NULL, and that parameter is determined from the others. Notice that the last one has non-NULL default so NULL must be explicitly passed if you want to compute it.

References

J. Cohen (1988) Statistical power analysis for the behavioral scientist. Lawrence Erlbaum Associates, publishers.

Examples

Run this code
## Exercise 3.1 p. 96 from Cohen (1988)
pwr.r.test(r=0.3,n=50,sig.level=0.05,alternative="two.sided")
pwr.r.test(r=0.3,n=50,sig.level=0.05,alternative="one.sided")

## Exercise 3.4 p. 208 from Cohen (1988)
pwr.r.test(r=0.3,power=0.80,sig.level=0.05,alternative="two.sided")
pwr.r.test(r=0.5,power=0.80,sig.level=0.05,alternative="two.sided")
pwr.r.test(r=0.1,power=0.80,sig.level=0.05,alternative="two.sided")

Run the code above in your browser using DataLab